projectal.entities.stage API documentation

# projectal.entities.stage

View Source

    from projectal.entity import Entity
    from projectal.linkers import *

    class Stage(Entity, ProjectLinker, TaskLinker):
        """
        Implementation of the [Stage](https://projectal.com/docs/latest/#tag/Stage) API.
        """
        _path = 'stage'
        _name = 'stage'
        _links_reverse = [ProjectLinker, TaskLinker]

class Stage(projectal.entity.Entity, projectal.linkers.ProjectLinker, projectal.linkers.TaskLinker):
View Source

    class Stage(Entity, ProjectLinker, TaskLinker):
        """
        Implementation of the [Stage](https://projectal.com/docs/latest/#tag/Stage) API.
        """
        _path = 'stage'
        _name = 'stage'
        _links_reverse = [ProjectLinker, TaskLinker]

Implementation of the Stage API.

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  entity_name
projectal.linkers.ProjectLinker
  link_project
  unlink_project
projectal.linkers.TaskLinker
  link_task
  unlink_task
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy